netapp_ontap.models.nfs_service_protocol_v41_features API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_protocol_v41_features`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceProtocolV41FeaturesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceProtocolV41Features object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `acl_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.1 or later ACLs is enabled.

  `implementation_domain: str GET POST PATCH`

    Specifies the NFSv4.1 or later implementation ID domain.

  `implementation_name: str GET POST PATCH`

    Specifies the NFSv4.1 or later implementation ID name.

  `pnfs_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.1 or later Parallel NFS is enabled.

  `read_delegation_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.1 or later Read Delegation is enabled.

  `referrals_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.1 referrals is enabled.

  `trunking_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.1 or later trunking is enabled.

  `write_delegation_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.1 or later Write Delegation is enabled.